# `NetboxBase` class

<!-- ::: netbox_proxbox.backend.routes.netbox.generic.NetboxBase
    options:
      docstring_options:
        ignore_init_summary: true
      merge_init_into_class: true
      show_source: false -->


nb is a dependency injection of [NetboxSessionDep][netbox_proxbox.backend.session.netbox.NetboxSessionDep]

!!! example "Teste"

    === "1"
        ```
        teste 01
        ```

    === "2"
        teste 02